@@ -11,11 +11,17 @@ class UnsupportedEvent(Exception):
     pass
 
 
+class InvalidFormat(Exception):
+    pass
+
+
 class Action(Enum):
     OPEN = 'open'
     UPDATE = 'update'
     MERGE = 'merge'
     APPROVED = 'approved'
+    CLOSE = 'close'
+    REOPEN = 'reopen'
 
 
 @dataclass
@@ -53,15 +59,34 @@ class MergeRequestEvent:
     @classmethod
     def from_dict(cls, event_dict: Dict[str, Any]) -> MergeRequestEvent:
 
-        if event_dict['event_type'] != 'merge_request':
+        try:
+            event_type = event_dict['event_type']
+        except KeyError as exc:
+            raise InvalidFormat('Missing event_type') from exc
+
+        if event_type != 'merge_request':
             raise UnsupportedEvent(
                 f'Only "merge_request" events are currently supported, got:'
-                f' {event_dict["event_type"]}'
+                f' {event_type}'
             )
 
         mr_attrs = event_dict['object_attributes']
 
-        action = Action(mr_attrs['action'])
+        try:
+            action_str = mr_attrs['action']
+        except KeyError as exc:
+            raise UnsupportedEvent(
+                'Only "merge_request" events with "action" in'
+                ' "object_attributes" are supported',
+            ) from exc
+
+        try:
+            action = Action(action_str)
+        except ValueError as exc:
+            raise UnsupportedEvent(
+                f'Unsupported "action" of "merge_request" event: {action_str}.'
+                f' Supported actions are: {[a.value for a in Action]}.',
+            ) from exc
 
         try:
             assignees_change_dict = event_dict['changes']['assignees']
@@ -115,16 +140,13 @@ class MergeRequestEvent:
             text = f'{self.short_link} *merged* by {self.event_author}.'
         elif self.action == Action.UPDATE:
             assert isinstance(self.assignees_change, AssigneesChange)
-            previous = format_users(users=self.assignees_change.previous)
-            current = format_users(
+            current_assignees = format_users(
                 users=self.assignees_change.current, mention=True
             )
-            text = '\n'.join(
-                (
-                    f'{self.short_link} *reassigned* by {self.event_author}',
-                    f'\tPrevious assignees: {previous}',
-                    f'\tCurrent assignees: {current}',
-                )
-            )
+            text = f'{self.short_link} *reassigned* to {current_assignees}'
+        elif self.action == Action.CLOSE:
+            text = f'{self.short_link} *closed* by {self.event_author}.'
+        elif self.action == Action.REOPEN:
+            text = f'{self.short_link} *reopened* by {self.event_author}.'
 
         return Message(text=text, thread_key=self.mr_id)
